@@ -10,7 +10,7 @@ use overload '""' => sub { shift->to_string }, fallback => 1;
 
 require Time::Local;
 
-__PACKAGE__->attr('epoch', chained => 1);
+__PACKAGE__->attr(epoch => (chained => 1));
 
 sub new {
     my $self = shift->SUPER::new();
@@ -28,7 +28,7 @@ sub parse {
     $self = $self->new unless ref $self;
 
     # Shortcut
-    return unless $date;
+    return unless defined $date;
 
     # epoch - 784111777
     if ($date =~ /^\d+$/) {
@@ -53,7 +53,7 @@ sub parse {
     # RFC822/1123 - Sun, 06 Nov 1994 08:49:37 GMT
     if ($date =~ /^(\d+)\s+(\w+)\s+(\d+)\s+(\d+):(\d+):(\d+)$/) {
         $day    = $1;
-        $month  = $months->{$2} || 1;
+        $month  = $months->{$2};
         $year   = $3;
         $hour   = $4;
         $minute = $5;
@@ -63,7 +63,7 @@ sub parse {
     # RFC850/1036 - Sunday, 06-Nov-94 08:49:37 GMT
     elsif ($date =~ /^(\d+)-(\w+)-(\d+)\s+(\d+):(\d+):(\d+)$/) {
         $day    = $1;
-        $month  = $months->{$2} || 1;
+        $month  = $months->{$2};
         $year   = $3;
         $hour   = $4;
         $minute = $5;
@@ -72,7 +72,7 @@ sub parse {
 
     # ANSI C asctime() - Sun Nov  6 08:49:37 1994
     elsif ($date =~ /^(\w+)\s+(\d+)\s+(\d+):(\d+):(\d+)\s+(\d+)$/) {
-        $month  = $months->{$1} || 1;
+        $month  = $months->{$1};
         $day    = $2;
         $hour   = $3;
         $minute = $4;
@@ -82,25 +82,29 @@ sub parse {
 
     # Invalid format
     else { return undef }
-    
+
     $self->epoch(
-      Time::Local::timegm($second, $minute, $hour, $day, $month, $year));
+        Time::Local::timegm($second, $minute, $hour, $day, $month, $year));
     return $self;
 }
 
 sub to_string {
     my $self = shift;
-    my $epoch = shift || $self->{epoch} || time;
+    my $epoch = shift || $self->{epoch};
 
-    my ($second, $minute, $hour, $mday, $month, $year, $wday)
-      = gmtime $epoch;
+    $epoch = time unless defined $epoch;
+
+    my ($second, $minute, $hour, $mday, $month, $year, $wday) = gmtime $epoch;
 
     my $days   = [qw/Sun Mon Tue Wed Thu Fri Sat/];
     my $months = [qw/Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec/];
 
     # Format
-    return sprintf("%s, %02d %s %04d %02d:%02d:%02d GMT", $days->[$wday],
-      $mday, $months->[$month], $year+1900, $hour, $minute, $second);
+    return sprintf(
+        "%s, %02d %s %04d %02d:%02d:%02d GMT",
+        $days->[$wday], $mday, $months->[$month], $year + 1900,
+        $hour, $minute, $second
+    );
 }
 
 1;
@@ -132,7 +136,10 @@ L<Mojo::Date> implements HTTP date and time functions according to RFC2616.
 =head2 C<epoch>
 
     my $epoch = $date->epoch;
-    $date     = $date->epoch(time);
+    $date     = $date->epoch(784111777);
+
+Returns epoch seconds if called without arguments.
+Returns the invocant if called with arguments.
 
 =head1 METHODS
 
@@ -147,8 +154,20 @@ following new ones.
 
     $date = $date->parse('Sun Nov  6 08:49:37 1994');
 
+Returns the invocant if the given date could be parsed successfully.
+Returns false otherwise.
+
+Parsable formats include:
+
+    - Epoch format (784111777)
+    - RFC 822/1123 (Sun, 06 Nov 1994 08:49:37 GMT)
+    - RFC 850/1036 (Sunday, 06-Nov-94 08:49:37 GMT)
+    - ANSI C asctime() (Sun Nov  6 08:49:37 1994)
+
 =head2 C<to_string>
 
     my $string = $date->to_string;
 
-=cut
\ No newline at end of file
+Returns a valid HTTP date according to RFC 822.
+
+=cut
