@@ -11,7 +11,7 @@ use base 'Mojo::File';
 use Carp 'croak';
 use IO::File;
 
-__PACKAGE__->attr('content', default => '');
+__PACKAGE__->attr(content => (default => ''));
 
 # There's your giraffe, little girl.
 # I'm a boy.
@@ -19,7 +19,7 @@ __PACKAGE__->attr('content', default => '');
 sub add_chunk {
     my ($self, $chunk) = @_;
     $self->{content} ||= '';
-    $self->{content}  .= $chunk;
+    $self->{content} .= $chunk;
     return $self;
 }
 
@@ -114,4 +114,4 @@ Moves the uploaded file contents to the given path and returns the invocant.
 
     my $string = $file->slurp;
 
-=cut
\ No newline at end of file
+=cut
