@@ -12,8 +12,8 @@ use File::Spec;
 use FindBin;
 use Mojo::Script;
 
-__PACKAGE__->attr('app_class',  chained => 1);
-__PACKAGE__->attr('parts',  chained => 1, default => sub { [] });
+__PACKAGE__->attr(app_class => (chained => 1));
+__PACKAGE__->attr(parts => (chained => 1, default => sub { [] }));
 
 # I'm normally not a praying man, but if you're up there,
 # please save me Superman.
@@ -61,7 +61,7 @@ sub detect {
             # Check for executable
             return $self->parts(\@home)
               if -f File::Spec->catfile(@home, 'bin', $name)
-              || -f File::Spec->catfile(@home, 'bin', 'mojo');
+                  || -f File::Spec->catfile(@home, 'bin', 'mojo');
         }
     }
 
@@ -237,4 +237,4 @@ Note that the UNIX style C</> is used as separator on all platforms.
 
 Return the path to projects root directory.
 
-=cut
\ No newline at end of file
+=cut
