@@ -16,12 +16,11 @@ require IO::File;
 use Mojo::ByteStream;
 use Mojo::Template;
 
-__PACKAGE__->attr('description', chained => 1, default => 'No description.');
-__PACKAGE__->attr('quiet', chained => 1, default => 0);
-__PACKAGE__->attr('renderer',
-    chained => 1,
-    default => sub { Mojo::Template->new }
-);
+__PACKAGE__->attr(
+    description => (chained => 1, default => 'No description.'));
+__PACKAGE__->attr(quiet => (chained => 1, default => 0));
+__PACKAGE__->attr(
+    renderer => (chained => 1, default => sub { Mojo::Template->new }));
 
 sub chmod_file {
     my ($self, $path, $mod) = @_;
@@ -146,7 +145,9 @@ sub render_data {
     my $template = $self->get_data($data);
 
     # Render
-    return $self->renderer->render($template, @_);
+    my $output;
+    $self->renderer->render($template, \$output, @_);
+    return $output;
 }
 
 sub render_to_file {
@@ -313,4 +314,4 @@ following new ones.
 
     $script = $script->write_rel_file('foo/bar.txt', 'Hello World!');
 
-=cut
\ No newline at end of file
+=cut
