@@ -9,7 +9,7 @@ use base 'Mojo::Script';
 
 use Mojo::Server::FastCGI;
 
-__PACKAGE__->attr('description', chained => 1, default => <<'EOF');
+__PACKAGE__->attr(description => (chained => 1, default => <<'EOF'));
 * Start the fastcgi script. *
 Takes no options.
     fastcgi
@@ -58,4 +58,4 @@ implements the following new ones.
 
     $fastcgi = $fastcgi->run(@ARGV);
 
-=cut
\ No newline at end of file
+=cut
