@@ -9,7 +9,7 @@ use base 'Mojo::Base';
 
 # Don't kid yourself, Jimmy. If a cow ever got the chance,
 # he'd eat you and everyone you care about!
-__PACKAGE__->attr('state', chained => 1, default => 'start');
+__PACKAGE__->attr(state => (chained => 1, default => 'start'));
 
 sub done { shift->state('done') }
 
@@ -24,6 +24,8 @@ sub has_error { return defined shift->{error} }
 
 sub is_done { return shift->state eq 'done' }
 
+sub is_finished { return shift->is_state(qw/done error/) }
+
 sub is_state {
     my ($self, @states) = @_;
     for my $state (@states) { return 1 if $self->state eq $state }
@@ -74,9 +76,16 @@ following new ones.
 
     my $done = $stateful->is_done;
 
+=head2 C<is_finished>
+
+    my $finished = $stateful->is_finished;
+
+Returns true if C<state> is C<done> or C<error>.
+Returns false otherwise.
+
 =head2 C<is_state>
 
     my $is_state = $stateful->is_state('writing');
     my $is_state = $stateful->is_state(qw/error reading writing/);
 
-=cut
\ No newline at end of file
+=cut
