@@ -7,6 +7,8 @@ use warnings;
 
 use base 'Mojo::Base';
 
+__PACKAGE__->attr(ctx => (chained => 1));
+
 # If we don't go back there and make that event happen,
 # the entire universe will be destroyed...
 # And as an environmentalist, I'm against that.
@@ -26,9 +28,17 @@ MojoX::Dispatcher::Routes::Controller - Controller Base Class
 
 L<MojoX::Dispatcher::Routes::Controller> is a controller base class.
 
+=head1 ATTRIBUTES
+
+=head2 C<ctx>
+
+    my $c = $controller->ctx;
+
+Returns a L<MojoX::Dispatcher::Routes::Context> object.
+
 =head1 METHODS
 
 L<MojoX::Dispatcher::Routes::Controller> inherits all methods from
 L<Mojo::Base>.
 
-=cut
\ No newline at end of file
+=cut
