@@ -7,7 +7,7 @@ use warnings;
 
 use base 'MojoX::Dispatcher::Routes';
 
-__PACKAGE__->attr([qw/method user_agent/], chained => 1);
+__PACKAGE__->attr([qw/method user_agent/] => (chained => 1));
 
 # That's not why people watch TV.
 # Clever things make people feel stupid and unexpected things make them feel
@@ -70,4 +70,4 @@ L<MojoX::Dispatcher::Routes> and implements the following new ones.
 
     my $match = $routes->match($tx);
 
-=cut
\ No newline at end of file
+=cut
