@@ -11,13 +11,10 @@ use base 'Mojo::Base';
 # I thought it would be fun and zany, like that movie Spaceballs.
 # But instead it was dark and disturbing. Like that movie... Police Academy.
 __PACKAGE__->attr('bananas');
-__PACKAGE__->attr([qw/ears eyes/], default => sub { 2 }, chained => 1);
+__PACKAGE__->attr([qw/ears eyes/], default => sub {2}, chained => 1);
 __PACKAGE__->attr('figs', default => 0);
-__PACKAGE__->attr('friend', {weak => 1});
-__PACKAGE__->attr('heads', {
-    default => 1,
-    filter  => sub { s/\D//g; $_ }
-});
-__PACKAGE__->attr('name', filter  => sub { lc });
+__PACKAGE__->attr('friend', {weak    => 1});
+__PACKAGE__->attr('heads',  {default => 1});
+__PACKAGE__->attr('name');
 
-1;
\ No newline at end of file
+1;
