@@ -10,8 +10,14 @@ use base 'Mojolicious::Controller';
 # If you're programmed to jump off a bridge, would you do it?
 # Let me check my program... Yep.
 sub index {
-    my ($self, $c) = @_;
-    $c->render;
+    my $self = shift;
+    $self->stash(msg => 'Hello World!');
+    $self->render;
+}
+
+sub templateless {
+    my $self = shift;
+    $self->render(format => 'test');
 }
 
 sub test {
@@ -21,4 +27,4 @@ sub test {
     $c->res->body($c->url_for(controller => 'bar'));
 }
 
-1;
\ No newline at end of file
+1;
